%%
%The following file is a companion to the PLOS One Publication:
%"Quasistatic Cavity Resonance for Ubiquitous Wireless Power Transfer"
% Matthew J. Chabalko 1, Mohsen Shahmohammadi 1, Alanson P. Sample 1*
%1 Disney Research, Pittsburgh, 4720 Forbes Avenue, Lower Level, Suite 110, Pittsburgh,
%PA 15213 USA
%* alanson.sample@disneyresearch.com
%Last edited November 30, 2016 by MJC


%%
clear all
close all

% First read in SIMULATED E-field magnitude, rho is in inches, E is reported in V_RMS/m (!!)
% Values obtained when 43 A was simulated to be injected into the pole as
% measured in experimental data collection (actually current in pole
% depends on how close E-field meter is to pole as it loads the resonator)
filename = 'Efield_rho_slice.txt';
delimiter = ' ';
startRow = 2;
formatSpec = '%f%f%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'HeaderLines' ,startRow-1, 'ReturnOnError', false);
fclose(fileID);
Rho = dataArray{:, 1};
EField = dataArray{:, 2};
clearvars filename delimiter startRow formatSpec fileID dataArray ans;

% Next read in MEASURED values of E-field Magnitude, Rho is in inches, E-magnitude measured in V_RMS/m

X=xlsread('E_Field_rhoSlice_z_level_79p5_inch_from_ground.xlsx');
Rho2=X(:,1);
EField2=X(:,2);

%load analytic results.  A single .txt file is also included for users without
%matlab
load('AnalyticE.mat')

% Lastly, plot the results, making Rho in meters, and making sure both E-magnitude are V_RMS/m
figure
semilogy(Rho2*2.54e-2,EField2,'bo-', Rho(1:end)*2.54e-2,EField(1:end),'k-', rhoEa, normE3,'rs-');
xlabel('Radial Distance (m)');
ylabel('Electric Field Norm (V-RMS/m)');
legend('|E|, measured', '|E|, simulation', '|E| analytic');
grid on
