%The following file is a companion to the PLOS One Publication:
%"Quasistatic Cavity Resonance for Ubiquitous Wireless Power Transfer"
% Matthew J. Chabalko 1, Mohsen Shahmohammadi 1, Alanson P. Sample 1*
%1 Disney Research, Pittsburgh, 4720 Forbes Avenue, Lower Level, Suite 110, Pittsburgh,
%PA 15213 USA
%* alanson.sample@disneyresearch.com
%Last edited November 30, 2016 by MJC


%%
%This code generates the measured and simulated portion of the plot in 
%4d of the main manuscript.  The analytic result is stored as .mat and .txt
%files (.txt is included if a user doesn't have matlab to deal with .mat
%files)....
%The raw S-parameter files from which this plot is obtained
%are included as freely available to the public.
%The Sparameter files are included as .mat files with the following format:

%Column #      1      2       3       4       5       6       7       8      9
%         Frequency Re(S11) Im(S11) Re(S12) Im(S12) Re(S21) Im(S21) Re(S22) Im(S22)

%Note the .mat file is simply formatted as typical .S2P files

%In addition, column 10's rows, from top to bottom are: 1 start frequency, 2 Stop Frequency, 
%3 IF Bandwidth, 4 Number of Data Points, 5 port impedance (50 ohms)

clear all
close all

%%
% First compute Gmax for the 8 data points that start at 6 inches away from
% the pole and extend to 90 inches away from the pole
index=0;
for m=6:12:90
    
index=index+1;    
load(strcat('C_Gmax_x_',num2str(m),'_in.mat'));

f=S(:,1);
S11=S(:,2)+1i*S(:,3);
S12=S(:,4)+1i*S(:,5);
S21=S(:,6)+1i*S(:,7);
S22=S(:,8)+1i*S(:,9);

for n=1:length(f)
    
    Smat=[S11(n), S12(n); S21(n), S22(n)];
    Gmax_raw(n)=powergain(Smat,'Gmag'); %Powergain requires the RF toolbox, the argument 'Gmag' computes Gmax, 
                                        %for a given input S-parameter matrix 
                                        %the maximum possible efficiency
                                        %assuming the network is perfectly
                                        %impedance matched with a lossless
                                        %impedance matching network and
                                        %allows direct comparison to
                                        %analytic calculations
    
end;

Gmax(index)=Gmax_raw(3073); %3073 is index when frequency is 1.322 MHz

end;

%%
%Next, read in and process simulated Gmax, where the raw file format is actual
%.s2p files, the simulations were only done at a single frequency (the
%resonant frequency 1.322 MHz. 
n=0;
for dist0=6:12:90
    n=n+1;
data_comsol = read(rfdata.data,strcat('Sim_Gmax_',num2str(dist0),'in.s2p'));
s_params_comsol = extract(data_comsol,'S_PARAMETERS',50);
Gmax_comsol(n)=powergain(s_params_comsol, 'Gmag')*100;
end;

Rho=[6 18 30 42 54 66 78 90]*2.54e-2;

%%
%load the analytic result for plotting
load('AnalyticGmax');

%%
%Finally, plot the results

plot(Rho,Gmax*100,'bo-', Rho, Gmax_comsol, 'kd-', rhoA,GmaxA,'r-')
grid on
ylim([0,100]);
xlabel('Radial Distance (m)');
ylabel('Gmax Efficiency-Measured, %');
