%%
%The following file is a companion to the PLOS One Publication:
%"Quasistatic Cavity Resonance for Ubiquitous Wireless Power Transfer"
% Matthew J. Chabalko 1, Mohsen Shahmohammadi 1, Alanson P. Sample 1*
%1 Disney Research, Pittsburgh, 4720 Forbes Avenue, Lower Level, Suite 110, Pittsburgh,
%PA 15213 USA
%* alanson.sample@disneyresearch.com
%Last edited November 30, 2016 by MJC


%%
clear all
close all

% First read in SIMULATED H-field magnitude, rho is in inches, H is in A/m
% (not A_RMS/m)...Values obtained when 47 A was simulated to be injected into the pole as
% measured in experimental data collection
filename = 'Comsol_Hfield_I0_47A.txt';
delimiter = ' ';
startRow = 2;
formatSpec = '%f%f%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'HeaderLines' ,startRow-1, 'ReturnOnError', false);
fclose(fileID);
Rho = dataArray{:, 1};
HField = dataArray{:, 2};
clearvars filename delimiter startRow formatSpec fileID dataArray ans;

% Next read in MEASURED values of H-field Magnitude, Rho is in inches, H-magnitude measured in A_RMS/m

X=xlsread('H_field_rho_slice.xlsx');
Rho2=X(:,1);
HField2=X(:,2);

%load analytic results.  A .txt file is also included for users without
%matlab
load('AnalyticH.mat')

% Lastly, plot the results, making Rho in meters, and making sure both H-magnitude are A_RMS/m
figure
semilogy(Rho2*2.54e-2,HField2,'bo-', Rho(1:end-10)*2.54e-2,HField(1:end-10)/sqrt(2),'k-', rhoH,Ha,'rs-');
xlabel('Radial Distance (m)');
ylabel('Magnetic Field Norm (A-RMS/m)');
legend('|H|, measured', '|H|, simulation', '|H| Analytic');
grid on
